<?xml version="1.0" encoding="iso-8859-1"?>
<?data type="list"?>
<?data table="book"?>
<?data recordspage="30"?>

<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="html"/>

<xsl:include href="Common.xsl"/>

<!--                                                                   -->
<!-- Display Covers in a Cover Flow style. Requires CATweb v2.0        -->
<!--   Template courtesy of LotsOCDs                                   -->
<!--                                                                   -->
<!-- For best results stored thumbnails should be 100 pixels high.     -->
<!--  Change the thumbnail size in the Database Setup window and then  -->
<!--  regenerate all thumbnails (Tools->Database Maintenenace).        -->
<!--  You can change the displayed dimensions in the settings below.   -->
<!--                                                                   -->
<!-- Option=1 - Do nothing about missing cover images (display blank)  -->
<!-- Option=2 - Show noimage.gif in place of missing cover images      -->
<!-- Option=3 - Skip missing cover images                              -->
<!--                                                                   -->
<xsl:variable name="cover_option">2</xsl:variable>
<xsl:variable name="cover_height">100</xsl:variable>
<xsl:variable name="cover_width" >66</xsl:variable>

<xsl:variable name="doctitle">
  <xsl:choose>
    <xsl:when test="data/recordset/title!=''">
      <xsl:value-of select="data/recordset/title"/>
    </xsl:when>
    <xsl:otherwise>
      <xsl:text>Book list</xsl:text>
    </xsl:otherwise>
  </xsl:choose>
</xsl:variable>

<xsl:template match="/">
  <HTML>
  <HEAD>
  <TITLE><xsl:value-of select="$doctitle"/><xsl:text> (page </xsl:text><xsl:value-of select="data/recordset/pageno"/>)</TITLE>
  <LINK REL="stylesheet" TYPE="text/css" HREF="style.css"/> 
  <link rel="stylesheet" href="imageflow.css" type="text/css" /> <!-- http://imageflow.finnrudolph.de/ -->
  <script src="imageflow.packed.js" type="text/javascript"></script>  
  </HEAD>
  <BODY>  
  <TABLE CLASS="pageheadinglist" CELLSPACING="0" CELLPADDING="4">
    <TR>
      <TD>
        <xsl:value-of select="$doctitle"/>        
      </TD>
    </TR>
  </TABLE>
  <BR/>
  <xsl:choose>
    <xsl:when test="data/recordset/totalrecords=0">
      No match!
      <P/>
      <B><A HREF="BACK">Back</A></B>
    </xsl:when>
    <xsl:otherwise>
      <!-- Display Covers in a Cover Flow style, works only with CATweb v2.0 -->
      <xsl:if test="/data/@dataserver='Yes'">
        <div id="wrapper">
          <center>
            <div id="myImageFlow" class="imageflow">
               <xsl:apply-templates select="data/record/bookdata" mode="cover"/>  
            </div> 
          </center>
        </div>
        <br/><br/>
      </xsl:if>     
      <!-- Page links -->
      <CENTER>
      <B>
      <xsl:call-template name="add-pagelinks">
        <xsl:with-param name="counter" select="1"/>
        <xsl:with-param name="totalpages" select="data/recordset/totalpages"/>
        <xsl:with-param name="pageno" select="data/recordset/pageno"/>
      </xsl:call-template>  
      </B>     
      </CENTER>
      <BR/>    
      <TABLE CLASS="tablerecords" CELLSPACING="1" CELLPADDING="2" WIDTH="100%">
        <!-- Column headings -->
        <TR CLASS="tablerecordsheadingrow">           
          <TD CLASS="tablerecordsheadingcell"><A HREF="orderby=Author,Title">Author</A></TD>
          <TD CLASS="tablerecordsheadingcell"><A HREF="orderby=Title">Title</A></TD>
          <TD CLASS="tablerecordsheadingcell"><A HREF="orderby=PersonalRating-d,Author,Title">Rating</A></TD>
          <TD CLASS="tablerecordsheadingcell"><A HREF="orderby=Publisher,Author,Title">Publisher</A><xsl:text>, </xsl:text>
              <A HREF="orderby=PublishDate,Author,Title">Year</A><xsl:text>, </xsl:text> 
              <A HREF="orderby=ISBN">ISBN</A><xsl:text>, </xsl:text> 
              <A HREF="orderby=ReferenceNo">Ref No</A></TD>
        </TR>
        <!-- List books -->
        <xsl:apply-templates select="data/record"/>
      </TABLE>
      <!-- Page links -->
      <P/>
      <CENTER>
      <B>
      <xsl:call-template name="add-pagelinks">
        <xsl:with-param name="counter" select="1"/>
        <xsl:with-param name="totalpages" select="data/recordset/totalpages"/>
        <xsl:with-param name="pageno" select="data/recordset/pageno"/>
      </xsl:call-template>  
      <P/>
      <xsl:call-template name="recordcount"/>
      </B>
      </CENTER>
    </xsl:otherwise>
  </xsl:choose>
  </BODY>  
  </HTML>
</xsl:template>

<xsl:template match="record">  
  <TR CLASS="tablerecordsrow">
    <xsl:attribute name="CLASS">
      <xsl:choose>
        <xsl:when test="position() mod 2 = 0">tablebgcolor1</xsl:when>
        <xsl:otherwise>tablebgcolor2</xsl:otherwise>
      </xsl:choose>
    </xsl:attribute>
    <xsl:apply-templates select="bookdata"/>
  </TR>
</xsl:template>

<xsl:template match="bookdata">    
  <TD CLASS="tablerecordscell" WIDTH="25%">
    <!-- Author -->
    <xsl:call-template name="format-author">
      <xsl:with-param name="authors" select="authors"/>
      <xsl:with-param name="newline" select="false"/>
    </xsl:call-template>
  </TD>
  <TD CLASS="tablerecordscell" WIDTH="30%">
    <!-- Title -->
    <B>
    <A HREF="Book.xsl?ID={../@id}"><xsl:value-of select="title"/></A>	
    </B>
  </TD>
  <TD CLASS="tablerecordscell" WIDTH="5%" NOWRAP="">
    <xsl:if test="personalrating/@image!=''">
      <IMG SRC="{personalrating/@image}" BORDER="0"/>
      <xsl:text> </xsl:text>
      <A HREF="CMD:SETRATING:Book,PersonalRating,{bookid/@unformatted}">
        <IMG SRC="SetRating.gif" BORDER="0"/>
      </A>        
    </xsl:if> 
  </TD>
  <TD CLASS="tablerecordscell" WIDTH="*">
    <!-- Publisher, Year, ISBN, RefNo -->
    <xsl:value-of select="publisher"/>
    <xsl:text>, </xsl:text>
    <xsl:value-of select="publishdate/@year"/>
    <xsl:if test="isbn!=''">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="isbn"/>
    </xsl:if>
    <xsl:if test="referenceno!=''">
      <xsl:text>, </xsl:text>
      <xsl:value-of select="referenceno"/>
    </xsl:if>
  </TD>
</xsl:template>

<xsl:template match="bookdata" mode="cover">
  <xsl:choose>
    <!-- Option 1 - Do nothing about missing cover images (display blank) -->
    <xsl:when test="$cover_option = 1">
      <img border="0" SRC="{image1/thumbnail}" longdesc="template=Book.xsl&amp;filter=ID={../@id}" height="{$cover_height}" width="{$cover_width}" alt="{title}">
    </img>
    </xsl:when>
    <!-- Option 2 - Show noimage.gif in place of missing cover images -->
    <xsl:when test="$cover_option = 2">
      <xsl:choose>
        <xsl:when test="image1/thumbnail= ''">
          <img border="0" SRC="noimage.gif" longdesc="template=Book.xsl&amp;filter=ID={../@id}" height="{$cover_height}" width="{$cover_width}" alt="{title}"/>
        </xsl:when>
        <xsl:otherwise>
          <img border="0" SRC="{image1/thumbnail}" longdesc="template=Book.xsl&amp;filter=ID={../@id}" height="{$cover_height}" width="{$cover_width}" alt="{title}">
          </img>
        </xsl:otherwise>
      </xsl:choose>      
    </xsl:when>
    <!-- Option 3 - Display nothing in place of missing cover images -->
    <xsl:when test="$cover_option = 3">
      <xsl:choose>
        <xsl:when test="image1/thumbnail= ''">
        </xsl:when>
        <xsl:otherwise>
          <img border="0" SRC="{image1/thumbnail}" longdesc="template=Book.xsl&amp;filter=ID={../@id}" height="{$cover_height}" width="{$cover_width}" alt="{title}"/>
        </xsl:otherwise>
      </xsl:choose>      
    </xsl:when>
    <xsl:otherwise>
      <img border="0" SRC="{image1/thumbnail}" longdesc="template=Album.xsl&amp;filter=ID={../@id}" height="{$cover_height}" width="{$cover_width}" alt="{title}"/>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

</xsl:stylesheet>  
